@@ -279,7 +279,7 @@
 #define HAVE_WCHAR_T 1
 #define HAVE_WINT_T 1
 #define HAVE_CURSES_H 1
-/* #undef HAVE_NCURSES_H */
+#define HAVE_NCURSES_H 1
 #define USE_LIBEDIT_INTERFACE 1
 #define HAVE_HIST_ENTRY 1
 #define USE_NEW_EDITLINE_INTERFACE 1
@@ -403,15 +403,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 38
-#define MYSQL_VERSION_EXTRA "-ndb-7.5.26"
+#define MYSQL_VERSION_PATCH 36
+#define MYSQL_VERSION_EXTRA "-ndb-7.6.20"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.38-ndb-7.5.26"
+#define PACKAGE_STRING "MySQL Server 5.7.36-ndb-7.6.20"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.38-ndb-7.5.26"
-#define VERSION "5.7.38-ndb-7.5.26"
+#define PACKAGE_VERSION "5.7.36-ndb-7.6.20"
+#define VERSION "5.7.36-ndb-7.6.20"
 #define PROTOCOL_VERSION 10
 
 /*
